<template>
  <div class="panel">
    <div id="openlayerContainer"></div>
  </div>
</template>
<script>
import store from "@/utils/store2.js";
import { setClick, leftClick, touchClick } from "@/utils/map2.js";
import _GLOBAL from "@/assets/GLOBAL2";
// import { leftClick, loadLayer } from "@/utils/map.js";
import {
  addHxLayer,
  addYzLayer,
  loadGeoMap,
  listenDirection,
  getCurrentPosition,
} from "@/utils/tool";

export default {
  name: "viewer2",
  components: {
    
  },
  data() {
    return {
      date: "",
      parentItem: {},
      childrendata: {
        fwval: true,
        zbzval: false,
        qpval: false,
        zymlval: false,
        zymlmenu: false,
        kjcxval: false,
        dxmsval: false,
        snmsval: false,
        ssval: true,
        zoomval: true,
      },
      timer: null,
      count: 0,
      state: store.history,
    };
  },
  created() {},
  mounted() {
    this.$nextTick(function () {
      ol.Map.prototype.getLayerByName = function (name) {
        var layer;
        this.getLayers().array_.forEach(function (lyr) {
          if (name == lyr.values_.name) {
            layer = lyr;
          }
        });
        return layer;
      };

      const layers = [];

      const TDTKey = "f234b950740b8c2e0d9959a51c169d21";
      const tiandituUrl = "http://t0.tianditu.gov.cn";
      let options = { proj: "EPSG:3857", layer: "img", matrixSets: "c" };
      let _proj = options.proj;
      let _layer = options.layer;
      let _key = TDTKey;
      let _matrixSets = options.matrixSets;

      let projection = ol.proj.get(_proj);
      let projectionExtent = projection.getExtent();
      let origin = projectionExtent
        ? ol.extent.getTopLeft(projectionExtent)
        : [-180, 90];
      let fromLonLat = ol.proj.getTransform("EPSG:3857", projection);
      let width = projectionExtent
        ? ol.extent.getWidth(projectionExtent)
        : ol.extent.getWidth(
            ol.extent.applyTransform([-180.0, -90.0, 180.0, 90.0], fromLonLat)
          );

      let resolutions = [];
      let matrixIds = [];
      for (let z = 1; z < 19; z++) {
        resolutions[z] = width / (256 * Math.pow(2, z));
        matrixIds[z] = z;
      }
      let wmtsTileGrid = new ol.tilegrid.WMTS({
        origin: origin,
        resolutions: resolutions,
        matrixIds: matrixIds,
      });
      console.log(
        "url:",
        `${tiandituUrl}/${_layer}_${_matrixSets}/wmts?tk=${_key}`
      );
      let wmtsSource = new ol.source.WMTS({
        url: `${tiandituUrl}/${_layer}_${_matrixSets}/wmts?tk=${_key}`,
        layer: _layer,
        version: "1.0.0",
        matrixSet: _matrixSets,
        format: "tiles",
        projection: projection,
        requestEncoding: "KVP",
        style: "default",
        tileGrid: wmtsTileGrid,
      });
      let wmtsLayer = new ol.layer.Tile({
        name: "影像地图",
        id: _layer + "_" + _matrixSets,
        source: wmtsSource,
      });

      let wmtsSource1 = new ol.source.WMTS({
        url: `${tiandituUrl}/cia_${_matrixSets}/wmts?tk=${_key}`,
        layer: "cia",
        version: "1.0.0",
        matrixSet: _matrixSets,
        format: "tiles",
        projection: projection,
        requestEncoding: "KVP",
        style: "default",
        tileGrid: wmtsTileGrid,
      });
      let wmtsLayer1 = new ol.layer.Tile({
        name: "路网图层",
        id: "cia_c",
        source: wmtsSource1,
      });

      let wmtsSource2 = new ol.source.WMTS({
        url: `${tiandituUrl}/vec_c/wmts?tk=${_key}`,
        layer: "vec",
        version: "1.0.0",
        matrixSet: _matrixSets,
        format: "tiles",
        projection: projection,
        requestEncoding: "KVP",
        style: "default",
        tileGrid: wmtsTileGrid,
      });
      let wmtsLayer2 = new ol.layer.Tile({
        name: "二维地图",
        id: "cva_c",
        source: wmtsSource2,
      });
      // wmtsLayer2.setVisible(false);
      ////二维地图
      // layers.push(wmtsLayer2);
      ////卫星影像
      // layers.push(wmtsLayer);
      ////路网
      // layers.push(wmtsLayer1);

      const map = new ol.Map({
        layers: layers,
        target: "openlayerContainer",
        view: new ol.View({
          center: ol.proj.fromLonLat([116.505348, 39.795592]),
          projection: "EPSG:3857",
          zoom: 11.5,
          minZoom: 7,
          maxZoom: 19.5,
          enableRotation: false,
          // constrainResolution: true,
          smoothResolutionConstraint: false,
        }),
      });

      window.mapapi = map;
      window.layersArray = window.mapapi.getLayers();
      // addImageLayer();
      // addAnnotationLayer();
      window.mapapi.getView().setZoom(14);
      loadGeoMap();
      // loadBaseMap();
      addHxLayer();
      addYzLayer();

      setClick(true);
      touchClick();

      getCurrentPosition();
      listenDirection();
      // leftClick()

      window.layerOpen = function (name, options) {
        layuiLayer.close(SmartEarthPopupData.layerProp);

        var width = options.width;
        var height = options.height;
        var offset = options.offset;
        var fn = options.fn || {};

        //获取相关回调事件
        var cancelFn = null;
        var successFn = null;
        var endFn = null;
        for (var key in fn) {
          cancelFn = key == "cancel" ? fn[key] : cancelFn;
          successFn = key == "success" ? fn[key] : successFn;
          endFn = key == "end" ? fn[key] : endFn;
        }

        SmartEarthPopupData.layerProp = layuiLayer.open({
          title: name,
          skin: "title-class",
          // title:false,
          type: 2, //0（信息框，默认）1（页面层）2（iframe层）3（加载层）4（tips层）
          // shade: options.shade !== undefined ? options.shade : 0.3,
          shade: 0,
          shadeClose: false,
          closeBtn: 1,
          resize: false,
          offset: offset,
          area: [
            typeof width === "number" ? width + "px" : width,
            // "100%",
            typeof height === "number" ? height + "px" : height,
          ],
          content: options.url,
          success: function (layero, index) {
            if (successFn && typeof successFn === "function") {
              successFn(layero, index);
            }
          },
          cancel: function () {
            if (cancelFn && typeof cancelFn === "function") {
              cancelFn();
            }
          },
          end: function () {
            if (endFn && typeof endFn === "function") {
              endFn();
            }
          },
        });
      };
    });
  },
  methods: {},
};
</script>
<style scoped>
.panel,
#openlayerContainer {
  width: 100%;
  height: 100%;
  background: black;
  /* position: absolute !important; */
  z-index: 0;
}

.titleBg {
  position: absolute;
  left: 0rem;
  top: 0rem;
  width: 100%;
  height: 0.43rem;
  background-color: #127eff;
  text-align: center;
  /* background-image: url("~@/assets/img/title/u2.png") !important;
  background-repeat: no-repeat;
  background-size: 100% 100% !important; */
}

.titleBg img {
  width: 207px;
  margin-top: 5px;
}

.bottomLeft {
  display: none;
}

.colseBtn {
  position: absolute;
  z-index: 2;
  top: 0.55rem;
  left: 0.2rem;
}

.colseBtn img {
  width: 30px;
}
</style>
